# $Id$
usage()
{
echo =================================================================
echo .
echo Usage : DBInfo.sh [DatabaseType] [ServerName] [DatabaseName]
echo    [WindowsAuthentication true/false] [DBPort] [UserName] [Password]
echo .
echo =================================================================
}

serverRunCheck()
{

msg="Firewall Analyzer Server is not running. Please ensure that the Firewall Analyzer Server should run before running this script"

. ../bin/setCommonEnv.sh

PRODUCT_HOME=..
TOOL_HOME=$PWD
BUILD_HOME=../troubleshooting
UPDATEMGR_LOGHOME=../logs
BIN_HOME=../bin
JAVA_HOME=../jre
CHERRY_HOME=../conf/server.xml
LOG_DIR=../logs
UTIL_CLASSPATH=../lib/LAClientUtil.jar:../lib/HTTPClient.jar
JAVA=$JAVA_HOME/bin/java

export TOOL_HOME
export BUILD_HOME
export UPDATEMGR_LOGHOME
export BIN_HOME
export JAVA_HOME
export CHERRY_HOME
export LOG_DIR 
export UTIL_CLASSPATH
export JAVA


	$JAVA -DContext=fw -Dserver.home=$PRODUCT_HOME -cp $UTIL_CLASSPATH com.adventnet.la.util.LAClientUtil $CHERRY_HOME 1

	if [ $? -ne 254 ]
	then
		echo "Firewall Analyzer Server is running."
	else
		echo $msg
	exit 1
	fi
	
#os=`uname -s`
#if [ "$os" = "Linux"  ]
#then
#rid=`id -u`
#if [ ${rid} -ne 0 ]
#    then
#    echo $msg
#    exit 1
#    fi
#fi
#
#if [ "$os" = "SunOS" ]
#then
#uid=`id | cut -d" " -f1`
#if [ "$uid" != "uid=0(root)" ]
#    then
#    echo $msg
#    exit 1
#    fi
#fi

}

initVar() {	
	fileName="datatables.list"
        dbType=$1
        dbName=$3
        dbPort=$5
        userName=$6
        if [ -z "$7"]
        then
                password=$7
        else
                password="--password="$7
        fi
        sysfile="sysinfo.log"
        logfile="databaseinfo.log"
        updatemgrlogfile="Log.txt"
        buildfile="build.properties"
        wrapperfile="wrapper.log"
        eefile="enterprise.txt"
        if [ "$dbType" == "mysql" ]
        then
                sock="../mysql/tmp/mysql.sock"
                mysqlString="../mysql/bin/mysql -S $sock  -u $userName $password $dbName"
        else
                mysqlString="$DB_HOME/bin/psql -U postgres $password -p $dbPort -h localhost $dbName"
        fi
}

getTableInfo() {
	log "Database Information"
	getVersion
	getCount FirewallRecords LRID
	getCount SquidRecords SQID
	getCount RadiusRecords RASID
	getLastData FirewallRecords LRID 
	getLastData SquidRecords SQID
	getLastData RadiusRecords RASID
	getCompleteData MetaTable
	getCompleteData Resources
	getCompleteData UnParsedRecords
	getCompleteData ImportedLogs
	getCompleteData FAArchivedFiles
	getCompleteData Schedule
	getCompleteData NotificationFilters
	getCompleteData ReportConfig
	getCompleteData ReportConfigToDF
	getCompleteData ReportConfigToFilters
	getCompleteData FilterToLAExpression
	getCompleteData LAExpression
	getCompleteData Collectors
	getCompleteData DataCollectionStatus
	log ""
}


getVersion()
{
	log "MySQL Version"
	echo "select version() " | $mysqlString >> ${logfile} 2>&1
		if [ $? -eq 0 ] 
		then
			echo "MySQL Version obtained"
		else
			log "Unable to get the MySQL Version"
			echo "Unable to get the MySQL Version"
		fi
	
}


getCount()
{
		log "$1 `date`"		
		echo "select count($2) from $1 " | $mysqlString >> ${logfile} 2>&1
		if [ $? -eq 0 ] 
		then
			echo "Info obtained for $1"
		else
			log "Unable to get info from $1"
			echo "Unable to get info from $1"
		fi
	
}

getLimitData()
{
		log "$1 `date`"
		echo "select * from $1 limit 1" | $mysqlString >> ${logfile} 2>&1
		if [ $? -eq 0 ]
		then
			echo "Info obtained for $1"
		else
			log "Unable to get info from $1"
			echo "Unable to get info from $1"
		fi

}

getLastData()
{
		log "$1 `date`"
		echo "select * from $1 order by $2 DESC limit 1" | $mysqlString >> ${logfile} 2>&1
		if [ $? -eq 0 ]
		then
			echo "Info obtained for $1"
		else
			log "Unable to get info from $1"
			echo "Unable to get info from $1"
		fi

}

getCompleteData()
{
		log "$1 `date`"	
		echo "select * from $1 " | $mysqlString >> ${logfile} 2>&1
		if [ $? -eq 0 ] 
		then
			echo "Info obtained for $1"
		else
			log "Unable to get info from $1"
			echo "Unable to get info from $1"
		fi
	
}

log() {
	message="$1"
    echo "---------------------------------------------------------------" >> ${logfile} 2>&1
	echo "${message}" >> ${logfile} 2>&1
    echo "--------------------------------------------" >> ${logfile} 2>&1
	#echo "${message}"
}

getTableList()
{
	touch $fileName
	touch temp.list
	echo "select LOOKUP_TABLENAME from MetaTable"|$mysqlString >> temp.list
	sed -e '1d' temp.list >> $fileName
	tableList=`cat $fileName`
	touch $logfile
}


removeLogFiles()
{
	for name in $fileName temp.list $logfile
	do
	if [ -r $name ]
		then
		echo  "Deleting previous $name"
		rm -r $name
	fi
	done
}



getDBSize()
{
	log "Data base size : "
	if [ "$dbType" == "mysql" ];
        then
                ls -lc ../mysql/data >> $logfile

                if [ -f ../mysql/data/*.err ];
                then
                        log "Copying ../mysql/data/*.err to $LOG_DIR"
                        echo "Copying ../mysql/data/*.err to $LOG_DIR"
                        cp ../mysql/data/*.err $LOG_DIR
                else
                        log "Unable to copy Mysql error file to $LOG_DIR"
                        echo "Unable to copy Mysql error file to $LOG_DIR"
                fi
        else
                echo "\l+"|$mysqlString >> ${logfile} 2>&1
        fi
	
}

copyToLogDir()
{

	if [ -f $TOOL_HOME/${logfile} ]; 
	then
		log "Copying ${logfile} to $LOG_DIR"
		cp ${logfile} $LOG_DIR
	else
		log "Unable to copy ${logfile} to $LOG_DIR"
		echo "Unable to copy ${logfile} to $LOG_DIR"
	fi
	
}

copyBuildProp()
{
	
	if [ -f $BUILD_HOME/${buildfile} ];
	then
		log "Copying ${buildfile} to $LOG_DIR"
		cp $BUILD_HOME/${buildfile} $LOG_DIR
	else
		log "Unable to copy build.properties to $LOG_DIR"
		echo "Unable to copy build.properties to $LOG_DIR"
	fi
}


copyUpdateMGRLogFile()
{
	
	if [ -f $UPDATEMGR_LOGHOME/${updatemgrlogfile} ];
	then
		log "Copying ${updatemgrlogfile} to $LOG_DIR"
		cp $UPDATEMGR_LOGHOME/${updatemgrlogfile} $LOG_DIR
	else
		log "Unable to copy Log.txt to $LOG_DIR"
		echo "Unable to copy Log.txt to $LOG_DIR"
	fi
}


copyWrapperLog()
{

	if [ -f $LOG_DIR/${wrapperfile} ];
	then
		echo "Wrapper.log exist in $LOG_DIR"
	else
		log "Copying ${wrapperfile} into $LOG_DIR"
		cp $BIN_HOME/${wrapperfile} $LOG_DIR
	fi
}

copyEnterpirseLog()
{
	if [ -f $PRODUCT_HOME/${eefile} ];
	then
		log "Copying ${eefile} into $LOG_DIR"
		cp $PRODUCT_HOME/${eefile} $LOG_DIR
	else
		log "Unable to copy enterprise.txt into $LOG_DIR"
		echo "Unable to copy enterprise.txt into $LOG_DIR"
	fi
}

copySysInfo()
{
	if [ ! -f $LOG_DIR/$sysfile ];
	then 
		echo "--------------------------------------" > $sysfile
		echo "memory info" >> $sysfile
		echo "--------------------------------------" >> $sysfile
		cat /proc/meminfo >> $sysfile
		echo "--------------------------------------" >> $sysfile
		echo "cpu info" >> $sysfile
		echo "--------------------------------------" >> $sysfile
		cat /proc/cpuinfo >> $sysfile
		if [ -f $BIN_HOME/$sysfile ];
		then
			log "Copying sysinfo.log into $LOG_DIR"
			cp $BIN_HOME/$sysfile $LOG_DIR
		else
			log "Unable to copy sysinfo.log into $LOG_DIR"
		fi
	fi
}

copyPglog()
{
	pglog=$(ls $DB_HOME/data/pg_log/*.log 2> /dev/null)

	if [ "$pglog" != "0" ];

	then
		log "Copying pgsql.log into $LOG_DIR"
		cp $DB_HOME/data/pg_log/*.log $LOG_DIR
	else
		log "Unable to copy pgsql.log into $LOG_DIR"
		echo "Unable to copy pgsql.log into $LOG_DIR"
	fi
}

main() 
{
	usage
	serverRunCheck 
	initVar $*
	removeLogFiles
	getTableList
	getTableInfo
	getDBSize
	copyBuildProp
	copyUpdateMGRLogFile
	copyWrapperLog
	copyEnterpirseLog
	copySysInfo
	copyPglog
	copyToLogDir
}

main $* 
